@@ -1,7 +1,6 @@
 """Convert dict into dataclass"""
 
 import dataclasses
-import inspect
 import logging
 from typing import Any, Dict, Iterable, List, Sized, Type, TypeVar, Union, cast
 
@@ -56,6 +55,9 @@ def into(value: V, kls: Type[T]) -> Result[T]:
                 "Since TypeVar is not supported, the type is assumed to be `Type`"
             )
             return value  # type: ignore
+        elif kls is None:
+            if value is None:
+                return value
         else:
             try:
                 if isinstance(value, kls):
@@ -66,29 +68,13 @@ def into(value: V, kls: Type[T]) -> Result[T]:
         return Error0(kls, value)
 
 
-def _is_class(value: Any) -> bool:
-    if inspect.isclass(value):
-        return True
-    return get_origin(value) is not None  # Generic alias
-
-
 def _into_type(value: Any, kls: Type[T]) -> Result[T]:
-    err = Error0(kls, value)
-    if not _is_class(value):
-        return err
-    expected: Type[T] = get_args(kls)[0]
-    if expected == Any or isinstance(expected, TypeVar):
-        return value
-
-    expected_orig = get_origin(expected) or expected
-    expected_args = get_args(expected)
-    orig = get_origin(value) or value
-    args = get_args(value)
-    if expected_orig == orig and (
-        not expected_args or not args or expected_args == args
-    ):
-        return value
-    return err
+    logger.warning(f"Checking {kls} is not supported.")
+    # There are many difficult cases in there, for example:
+    # - None
+    # - List == list
+    # For now, I don't validate `value` and pass it.
+    return value
 
 
 def _into_literal(value: V, kls: Type[T]) -> Result[T]:
@@ -207,5 +193,5 @@ def _into_dataclass(value: V, kls: Type[T]) -> Result[T]:
         d[k] = v
     try:
         return kls(**d)  # type: ignore
-    except:
-        return Error0(kls, value)
+    except Exception as e:
+        return Error0(kls, value, exception=e)
